--Frame Create
local lagMonitorFrame = CreateFrame("Frame", "LagMonitorFrame", UIParent);
local homePingFrame = CreateFrame("Frame", "HomePingFrame", lagMonitorFrame);
local worldPingFrame = CreateFrame("Frame", "WorldPingFrame", lagMonitorFrame);
local fpsFrame = CreateFrame("Frame", "FPSFrame", lagMonitorFrame);
local ilevelFrame = CreateFrame("Frame", "ItemLevelFrame", lagMonitorFrame);
local currencyFrame = CreateFrame("Frame", "CurrencyFrame", lagMonitorFrame);


--FontStrings(PingFrame)
local pingLocal = homePingFrame:CreateFontString("PLocal", "OVERLAY");
local pingWorld = worldPingFrame:CreateFontString("PWorld", "OVERLAY");
local pLocal = homePingFrame:CreateFontString("PLocal", "OVERLAY");
local pWorld = worldPingFrame:CreateFontString("PWorld", "OVERLAY");
local gFPS = fpsFrame:CreateFontString("GFPS", "OVERLAY");
local gameFPS = fpsFrame:CreateFontString("GFPS", "OVERLAY");

--FontStrings(IlevelFrame)
local ilevel = ilevelFrame:CreateFontString("ILVL", "OVERLAY");
local ilevelStats = ilevelFrame:CreateFontString("ILVLS", "OVERLAY");

--FontStrings(CurrencyFrame)
local gold = currencyFrame:CreateFontString("GOLD", "OVERLAY");

--Variables
local updateInterval = 0;
local addonLoadedMessage = 'v1.9A';
local defaultFont = 1;
local defaultFrameWidth = 250;
local defaultFrameHeight = 25;

--LibSharedMedia
local LSM = LibStub("LibSharedMedia-3.0");
LagMonitor = LibStub("AceAddon-3.0"):NewAddon("LagMonitor", "AceConsole-3.0", "AceEvent-3.0")

--Global variables
local userFont = {
		"Frizqt(Game - Default)",
		"Skurri(Game)",
		"Morpheus(Game)",
		"Arialn(Game)",
		"Shangri-la",
		"Bascula College",
		"Sigismundus",
		"Seasrn",
		"Caviar Dreams",
		"Blkchry",
		"Carnevalee Freakshow",
		"Good Times",
		"Price Down"
}

local userEdge = "Edge1";

local myFont = LSM:Fetch("font",userFont);
local edgeFile = LSM:Fetch("edge", userEdge);

--HomePingFrame
local HomePingBorder=homePingFrame:CreateTexture(nil,"BACKGROUND")
local HomePingBody=homePingFrame:CreateTexture(nil,"ARTWORK")

--WorldPingFrame
local WorldPingBorder=worldPingFrame:CreateTexture(nil,"BACKGROUND")
local WorldPingBody=worldPingFrame:CreateTexture(nil,"ARTWORK")

--FPSFrame
local FPSBorder=fpsFrame:CreateTexture(nil,"BACKGROUND")
local FPSBody=fpsFrame:CreateTexture(nil,"ARTWORK")

--ilevelFrame
local IlevelBorder=ilevelFrame:CreateTexture(nil,"BACKGROUND")
local IlevelBody=ilevelFrame:CreateTexture(nil,"ARTWORK")

--CurrencyFrame
local CurrencyBorder=currencyFrame:CreateTexture(nil,"BACKGROUND")
local CurrencyBody=currencyFrame:CreateTexture(nil,"ARTWORK")

local OnMouseDown = function(lagMonitorFrame, button)
    if button == "LeftButton" then
        lagMonitorFrame:StartMoving()
        lagMonitorFrame.isMoving = true
        lagMonitorFrame.hasMoved = false
    --elseif button == "RightButton" then
        --lagMonitorFrame:StartSizing()
        --lagMonitorFrame.isMoving = true
        --lagMonitorFrame.hasMoved = false
    end
end

function OnMouseUp(lagMonitorFrame)
    if ( lagMonitorFrame.isMoving ) then
        lagMonitorFrame:StopMovingOrSizing();
        lagMonitorFrame.isMoving = false;
        lagMonitorFrame.hasMoved = true;
    end
end

function OnHide(lagMonitorFrame)       
    if ( lagMonitorFrame.isMoving ) then
        lagMonitorFrame:StopMovingOrSizing();
        lagMonitorFrame.isMoving = false;
    end
end

lagMonitorFrame:RegisterForDrag("LeftButton","RightButton");
lagMonitorFrame:EnableMouse(true);
lagMonitorFrame:SetMovable(true);
lagMonitorFrame:SetResizable(true);
lagMonitorFrame:SetScript("OnMouseDown",OnMouseDown);
lagMonitorFrame:SetScript("OnMouseUp", OnMouseUp);
lagMonitorFrame:SetScript("OnHide", OnHide);

function framePositions()
--Set Frame (LagMonitorFrame)
	lagMonitorFrame:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	lagMonitorFrame:SetSize(250, 125)

--Set frame (ilevelFrame)
	ilevelFrame:SetPoint("BOTTOM", LagMonitorFrame, "BOTTOM", 0, -20)
	ilevelFrame:SetSize(defaultFrameWidth, defaultFrameHeight)

--Set frame (HomePingFrame)
	homePingFrame:SetPoint("TOP", LagMonitorFrame, "TOP", 0, -15)
	homePingFrame:SetSize(defaultFrameWidth, defaultFrameHeight)

--Set frame (WorldPingFrame)
	worldPingFrame:SetPoint("CENTER", LagMonitorFrame, "CENTER", 0, 0)
	worldPingFrame:SetSize(defaultFrameWidth, defaultFrameHeight)

--Set frame (FPSFrame)
	fpsFrame:SetPoint("BOTTOM", LagMonitorFrame, "BOTTOM", 0, 15)
	fpsFrame:SetSize(defaultFrameWidth, defaultFrameHeight)

--Set frame (CurrencyFrame)
	currencyFrame:SetPoint("TOP", LagMonitorFrame, "TOP", 0, 20)
	currencyFrame:SetSize(defaultFrameWidth, defaultFrameHeight)
end

framePositions();

--Register addon loaded
homePingFrame:RegisterEvent("ADDON_LOADED");
worldPingFrame:RegisterEvent("ADDON_LOADED");
fpsFrame:RegisterEvent("ADDON_LOADED");
ilevelFrame:RegisterEvent("ADDON_LOADED");
currencyFrame:RegisterEvent("ADDON_LOADED");
--Register player logout
homePingFrame:RegisterEvent("PLAYER_LOGOUT");
worldPingFrame:RegisterEvent("PLAYER_LOGOUT");
fpsFrame:RegisterEvent("PLAYER_LOGOUT");
ilevelFrame:RegisterEvent("PLAYER_LOGOUT");
currencyFrame:RegisterEvent("PLAYER_LOGOUT");

--Slash commands
SLASH_PING1 = "/ping";
SLASH_PING2 = "/latency";
SLASH_PING3 = "/ms";
SLASH_FPS1 = "/lmfps";
SLASH_FPS2 = "/framerate";
SLASH_FPS3 = "/fps";
SLASH_RESET1 = "/lmreset";
SLASH_ITEM1 = "/lmilvl";
SLASH_ITEM2 = "/ilvl";
SLASH_GOLD1 = "/gold";
SLASH_GOLD2 = "/currency";
SLASH_GOLD3 = "/money";
SLASH_HELP1 = "/lmhelp";
SLASH_HELP2 = "/lminfo";
SLASH_CLOSE1 = "/lmclose";
SLASH_CLOSE2 = "/lmexit";
SLASH_DISPLAY1 = "/lmdisplay";
SLASH_DISPLAY2 = "/lmopen";

SlashCmdList["DISPLAY"] = function(self, txt)
    LagMonitor.db.profile.closed = false;
	LagMonitorFrame:Show();
end

SlashCmdList["CLOSE"] = function(self, txt)
    LagMonitor.db.profile.closed = true;
	LagMonitorFrame:Hide();
end

SlashCmdList["HELP"] = function(self, txt)
	LagMonitor:Print("Commands available to use!");
	LagMonitor:Print("/ping - Displays home/world latency!");
	LagMonitor:Print("/fps - Displays the current frames per second!");
	LagMonitor:Print("/lmreset - Resets the addon to default settings!");
	LagMonitor:Print("/ilvl - Displays the item level of your character!");
	LagMonitor:Print("/gold - Displays the gold of your character!");
end

SlashCmdList["ITEM"] = function(self, txt)
	local overall, equipped = GetAverageItemLevel();
	LagMonitor:Print("Equipped Gear Item Level: " .. equipped);
	LagMonitor:Print("Overall Gear Item Level: " .. overall);
end

SlashCmdList["FPS"] = function(self, txt)
	local fps = GetFramerate();
	LagMonitor:Print("Framerate: " .. floor(fps));
	LagMonitor:Print(LagMonitor.db.profile.allFrameHeight);
end

SlashCmdList["RESET"] = function(self, txt)
	ResetSettings();
end

SlashCmdList["PING"] = function(self, txt)
	local up, down, home, world = GetNetStats();
	LagMonitor:Print("Home ping: " .. home);
	LagMonitor:Print("World ping: " .. world);
end

SlashCmdList["GOLD"] = function(self, txt)
	local copper = GetMoney()
	LagMonitor:Print(GetCoinTextureString(copper))
end

function round(number, decimals)
	return (("%%.%df"):format(decimals)):format(number)
end

local options = {
    name = "LagMonitor " .. addonLoadedMessage,
    handler = LagMonitor,
    type = 'group',
    args = {
	
        showColText = {
            type = "toggle",
            name = "Toggle Colors",
			order = 1,
            get = "IsShowColText",
            set = "ToggleShowColText",
        },
		fontThickOutline = {
			type = "toggle",
			name = "Font Thick Outline",
			order = 2,
			get = "IsThickOutline",
			set = "ToggleThickOutline"
		},
        closed = {
            type = "toggle",
            name = "Close",
			order = 3,
            get = "IsClosed",
            set = "ToggleIsClosed"
        },
		showItemLevel = {
		    type = "toggle",
            name = "Item Level",
			order = 4,
            get = "ShowItemLevel",
            set = "ToggleItemLevel"
        },
		showCurrency = {
		    type = "toggle",
            name = "Currency",
			order = 5,
            get = "ShowCurrency",
            set = "ToggleCurrency"
        },
		bordercol = {
			type = "range",
			name = "Outer Transparency",
			order = 6,
			min = 0,
			max = 1,
			get = "currentBorderCol",
			set = "changeBorderCol",
			step = 0.01
		},
		backgroundcol = {
			type = "range",
			name = "Inner Transparency",
			order = 7,
			min = 0,
			max = 1,
			get = "currentBackgroundCol",
			set = "changeBackgroundCol",
			step = 0.01
		},
		changeFont = {
			type = "range",
			name = "Change Font Size",
			order = 8,
			min = 7,
			max = 32,
			get = "currentFontSize",
			set = "changeFontSize",
			step = 1
		},
		activeFont = {
			type = "select",
			name = "Fonts",
			order = 9,
			values = userFont,
			get = "currentFont",
			set = "changeFont"
		},
		reset = {
			type = "execute",
			name = "Reset",
			order = 10,
			func = "ToggleIsReset"
		},
    },
}

function LagMonitor:ShowItemLevel(info)
	return self.db.profile.showItemLevel;
end

function LagMonitor:ShowCurrency(info)
	return self.db.profile.showCurrency;
end

function LagMonitor:ToggleItemLevel(info, value)
	self.db.profile.showItemLevel = value;
	if value == true then
		ItemLevelFrame:Show();
	end
	if value == false then
		ItemLevelFrame:Hide();
	end
end

function LagMonitor:ToggleCurrency(info, value)
	self.db.profile.showCurrency = value;
	if value == true then
		currencyFrame:Show();
	end
	if value == false then
		currencyFrame:Hide();
	end
end

function LagMonitor:IsThickOutline(info)
	return self.db.profile.thickOutline;
end

function LagMonitor:ToggleThickOutline(info, value)
	self.db.profile.thickOutline = value;
end

function LagMonitor:currentFont(info)
	return self.db.profile.activeFont;
end

function LagMonitor:changeFont(info, value)
	self.db.profile.activeFont = value;
	myFont = LSM:Fetch("font","Font" .. value);
end

function LagMonitor:currentFontSize(info)
	return self.db.profile.fontSize
end

function LagMonitor:currentBorderCol(info)
	return self.db.profile.bordercol
end

function LagMonitor:currentBackgroundCol(info)
	return self.db.profile.backgroundcol
end

function LagMonitor:changeBorderCol(info, value)
	self.db.profile.bordercol = value;
	HomePingBorder:SetVertexColor(0.85, 0.85, 0.85, value);
	WorldPingBorder:SetVertexColor(0.85, 0.85, 0.85, value);
	FPSBorder:SetVertexColor(0.85, 0.85, 0.85, value);
	IlevelBorder:SetVertexColor(0.85, 0.85, 0.85, value);
	CurrencyBorder:SetVertexColor(0.85, 0.85, 0.85, value);
end

function LagMonitor:changeBackgroundCol(info, value)
	self.db.profile.backgroundcol = value;
	HomePingBody:SetVertexColor(0.1, 0.1, 0.1, value);
	WorldPingBody:SetVertexColor(0.1, 0.1, 0.1, value);
	FPSBody:SetVertexColor(0.1, 0.1, 0.1, value);
	IlevelBody:SetVertexColor(0.1, 0.1, 0.1, value);
	CurrencyBody:SetVertexColor(0.1, 0.1, 0.1, value);
end

function LagMonitor:changeFontSize(info, value)
	self.db.profile.fontSize = value;
end

function LagMonitor:ToggleIsReset(info, value)
	ResetSettings();
end

function LagMonitor:IsShowColText(info)
    return self.db.profile.showColText
end

function LagMonitor:ToggleShowColText(info, value)
    self.db.profile.showColText = value
	ShowColText();
end

function LagMonitor:IsClosed(info)
    return self.db.profile.closed
end

function LagMonitor:ToggleIsClosed(info, value)
    self.db.profile.closed = value
	if value == true then
		LagMonitorFrame:Hide();
	end
	if value == false then
		LagMonitorFrame:Show();
	end
end

local defaults = {
    profile = {
        showColText = true,
		showItemLevel = false,
		showCurrency = false,
        closed = false,
		fontSize = 15,
		bordercol = 0.5,
		backgroundcol = 1,
		activeFont = defaultFont,
		thickOutline = false,
    },
}

function LagMonitor:OnInitialize()
    -- Called when the addon is loaded
	self:Print(addonLoadedMessage .. " Loaded!")
	self.db = LibStub("AceDB-3.0"):New("LagMonitorDB", defaults, true)
    LibStub("AceConfig-3.0"):RegisterOptionsTable("LagMonitor", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("LagMonitor", "LagMonitor")
end

function currencyFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
	
		OutlineSetting();
		
		AddonLoaded();
		
		declareFont();
		
		frameDeclare(CurrencyBorder, CurrencyBody, currencyFrame);
		
		gold:SetPoint("RIGHT", currencyFrame, "RIGHT", -10, 0);
		
		gold:SetTextColor(1, 1, 0, 1);
	end
end

currencyFrame:SetScript("OnEvent", currencyFrame.OnEvent);

function ilevelFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
		
		OutlineSetting();
		
		AddonLoaded();
		
		declareFont();
		
		frameDeclare(IlevelBorder, IlevelBody, ilevelFrame);
		
		ilevel:SetPoint("LEFT", ilevelFrame, "LEFT", 0, 0);
		
		ilevelStats:SetPoint("RIGHT", ilevelFrame, "RIGHT", 0, 0);
		ilevelStats:SetTextColor(1, 1, 0, 1);
		
		ilevel:SetTextColor(1, 1, 0, 1);
		
		ilevel:SetFormattedText("ILevel:");
	end
end

ilevelFrame:SetScript("OnEvent", ilevelFrame.OnEvent);

function homePingFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
	
		OutlineSetting();
		
		AddonLoaded();
		
		frameDeclare(HomePingBorder, HomePingBody, homePingFrame);
		
		declareFont();
		
		--Assign Local ping fonts
		pingLocal:SetPoint("RIGHT", homePingFrame, "TOPRIGHT", 0, -12);
		--Assign Game fps fonts
		pLocal:SetPoint("LEFT", homePingFrame, "TOPLEFT", 0, -12);
		pLocal:SetTextColor(1, 1, 0, 1);
		pLocal:SetFormattedText("Home(ms):");
	end
end

homePingFrame:SetScript("OnEvent", homePingFrame.OnEvent);

function worldPingFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
	
		OutlineSetting();
		
		AddonLoaded();
		
		frameDeclare(WorldPingBorder, WorldPingBody, worldPingFrame);
		
		declareFont();
		
		--Assign World ping fonts
		pingWorld:SetPoint("RIGHT", worldPingFrame, "RIGHT", 0, 0);
		--Assign Game fps fonts
		pWorld:SetPoint("LEFT", worldPingFrame, "LEFT", 0, 0);		
		pWorld:SetTextColor(1, 1, 0, 1);
		pWorld:SetFormattedText("World(ms):");
	end
end

worldPingFrame:SetScript("OnEvent", worldPingFrame.OnEvent);

function fpsFrame:OnEvent(event, arg1)
	if event == "ADDON_LOADED" and arg1 == "LagMonitor" then
	
		OutlineSetting();
		
		AddonLoaded();
		
		frameDeclare(FPSBorder, FPSBody, fpsFrame);
		
		declareFont();
		
		--Assign Game fps fonts
		gameFPS:SetPoint("RIGHT", fpsFrame, "BOTTOMRIGHT" , 0, 12);		
		--Assign Game fps fonts
		gFPS:SetPoint("LEFT", fpsFrame, "BOTTOMLEFT", 0, 12);		
		gFPS:SetTextColor(1, 1, 0, 1);
		gFPS:SetFormattedText("FPS:");
	end
end

fpsFrame:SetScript("OnEvent", fpsFrame.OnEvent);

function frameDeclare(border, body, frame)
		border:SetTexture(edgeFile)
		border:SetPoint("TOPLEFT",-5,5)
		border:SetPoint("BOTTOMRIGHT",5,-5)
		border:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol)

		
		body:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
		body:SetAllPoints(frame)
		body:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol)
end
	
function declareFont()
myFont = LSM:Fetch("font","Font" .. LagMonitor.db.profile.activeFont);
end

function AddonLoaded()
		if LagMonitor.db.profile.closed == true then
			LagMonitorFrame:Hide();
		end
		if LagMonitor.db.profile.closed == false then
			LagMonitorFrame:Show();
		end
		if LagMonitor.db.profile.showCurrency == true then
			currencyFrame:Show();
		end
		if LagMonitor.db.profile.showCurrency == false then
			currencyFrame:Hide();
		end
		if LagMonitor.db.profile.showItemLevel == true then
			ItemLevelFrame:Show();
		end
		if LagMonitor.db.profile.showItemLevel == false then
			ItemLevelFrame:Hide();
		end
end

function iLevelSetting()
	local overall, equipped = GetAverageItemLevel();
	rOverall = round(overall, 1);
	rEquipped = round(equipped, 1);
	if equipped ~= overall then
		ilevelStats:SetFormattedText(rEquipped .. "/" .. rOverall);
	end
	if equipped == overall then
		ilevelStats:SetFormattedText(rEquipped);
	end
end

local function onUpdate(self, elapsed)

iLevelSetting();

OutlineSetting();

FontUpdate();
	
updateInterval = updateInterval + elapsed
	if updateInterval >= 1 then	
		ShowColText();	
		goldUpdate();
		updateInterval = 0;
	end
end

lagMonitorFrame:SetScript("OnUpdate", onUpdate);

function FontUpdate()
if LagMonitor.db.profile.activeFont == defaultFont then
	LagMonitor.db.profile.activeFont = defaultFont;
end
end

function OutlineSetting()
--Change font sizes
fontSetting(pingLocal);
fontSetting(pingWorld);
fontSetting(gameFPS);
fontSetting(pLocal);
fontSetting(pWorld);
fontSetting(gFPS);
fontSetting(ilevel);
fontSetting(ilevelStats);
fontSetting(gold);
end

function fontSetting(text)
local textFontSize = LagMonitor.db.profile.fontSize;
local outline = LagMonitor.db.profile.thickOutline;

if outline == false then
text:SetFont(myFont,textFontSize,"OUTLINE")
end
if outline == true then
text:SetFont(myFont,textFontSize,"THICKOUTLINE")
end
end

function goldUpdate()
	local copper = GetMoney()
	gold:SetFormattedText(GetCoinTextureString(copper))
end

function ShowColText()
	local up, down, home, world = GetNetStats();
	local fps = GetFramerate();

				if LagMonitor.db.profile.showColText == true then
				if home < 250 then
				pingLocal:SetTextColor(0, 1, 0, 1);
				end
				if ((home >= 250) and (home < 400)) then
				pingLocal:SetTextColor(1, 1, 0, 1);
				end
				if home >= 400 then
				pingLocal:SetTextColor(1, 0, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				pingLocal:SetTextColor(1, 1, 0, 1);
			end
			--Display Local ping
			pingLocal:SetFormattedText(home);
	
				if LagMonitor.db.profile.showColText == true then
				if world < 250 then
				pingWorld:SetTextColor(0, 1, 0, 1);
				end
				if ((world >= 250) and (world < 400)) then
				pingWorld:SetTextColor(1, 1, 0, 1);
				end
				if world >= 400 then
				pingWorld:SetTextColor(1, 0, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				pingWorld:SetTextColor(1, 1, 0, 1);
			end
			--Display World ping
			pingWorld:SetFormattedText(world);

			--Display Game FPS
				if LagMonitor.db.profile.showColText == true then
				if floor(fps) <= 30 then
				gameFPS:SetTextColor(1, 0, 0, 1);
				end
				if ((floor(fps) > 30) and (floor(fps) <= 60)) then
				gameFPS:SetTextColor(1, 1, 0, 1);
				end
				if floor(fps) > 60 then
				gameFPS:SetTextColor(0, 1, 0, 1);
				end
			end
			if LagMonitor.db.profile.showColText == false then
				gameFPS:SetTextColor(1, 1, 0, 1);
			end
			gameFPS:SetFormattedText(floor(fps));
end

function ResetSettings()
--Reset Variables
	LagMonitor.db.profile.showColText = true;
	LagMonitor.db.profile.closed = false;
	LagMonitor.db.profile.showCurrency = false;
	LagMonitor.db.profile.showItemLevel = false;
	LagMonitor.db.profile.backgroundcol = 1;
	LagMonitor.db.profile.bordercol = 0.5;
	
--Show Frames
	AddonLoaded();

--Reset Points
	lagMonitorFrame:ClearAllPoints();
	lagMonitorFrame:SetPoint("CENTER");
	
--Reset frame positions
	framePositions();
	
--Reset Appearance	
	HomePingBorder:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol);
	HomePingBody:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol);
	WorldPingBorder:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol);
	WorldPingBody:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol);
	FPSBorder:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol);
	FPSBody:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol);
	IlevelBorder:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol);
	IlevelBody:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol);
	CurrencyBorder:SetVertexColor(0.85, 0.85, 0.85, LagMonitor.db.profile.bordercol);
	CurrencyBody:SetVertexColor(0.1, 0.1, 0.1, LagMonitor.db.profile.backgroundcol);
	
--Reset Size
	homePingFrame:SetSize(defaultFrameWidth, defaultFrameHeight)
	worldPingFrame:SetSize(defaultFrameWidth, defaultFrameHeight)
	fpsFrame:SetSize(defaultFrameWidth, defaultFrameHeight)
	ilevelFrame:SetSize(defaultFrameWidth, defaultFrameHeight)
	currencyFrame:SetSize(defaultFrameWidth, defaultFrameHeight)

--Reset Fonts
	LagMonitor.db.profile.fontSize = 15;
	LagMonitor.db.profile.thickOutline = false;
	LagMonitor.db.profile.activeFont = defaultFont;
	myFont = LSM:Fetch("font","Font" .. defaultFont);
	LagMonitor:Print("Reset to default settings!");
end